# coding: utf8

from __future__ import print_function

import numpy as np
import pandas as pd
import evaltools as evt
from sys import argv
from os.path import isdir, isfile
from distutils.dir_util import mkpath
from multiprocessing import Pool, Process
import matplotlib.pyplot as plt
from matplotlib.ticker import AutoMinorLocator
from matplotlib import cm
from datetime import datetime, date, timedelta, time

obs_path = "../doc/sample_data/observations/{year}_{species}_{station}"
sim_path = "../doc/sample_data/{model}{runtype}/J{forecastDay}/{year}_{species}_{station}"

listing_path = "../doc/sample_data/listing"
stations = evt.utils.read_listing(listing_path, classes='all', types='all', area_coord=None)

startDate = date(2017, 6, 1)
endDate = date(2017, 6, 4)

model_list = ["ENS", "MFM"]
model_colors = {"ENS": '#CB025A', "MFM": '#004D8A'}
species = 'no2'

observations = evt.evaluator.Observations.fromTimeSeries(
    generic_file_path=obs_path.format(year="{year}", species=species, station="{station}"),
    correc_unit=1e9,
    species=species,
    start=startDate,
    end=endDate,
    stations = stations,
    forecastHorizon=4)

persistence = observations.persistenceModel()

observations = observations.subPeriod(startDate+timedelta(1), endDate)

objs = {}
dailyObjs = {}
fh = 4
for model in model_list:
    generic_file_path = sim_path.format(model=model, runtype='forecast', forecastDay='{forecastDay}',
                                                           year='{year}', species=species, station='{station}')
    stationsIdx = observations.stations.index
    simulations = evt.evaluator.Simulations.fromTimeSeries(
        generic_file_path=generic_file_path,
        stationsIdx=stationsIdx,
        forecastHorizon=fh,
        correc_unit=1,
        species=species,
        model=model,
        start=startDate+timedelta(1),
        end=endDate)
    objs[model] = evt.evaluator.Evaluator(observations, simulations, color=model_colors[model])
    dailyObjs[model] = objs[model].dailyMax()

print("medianStationScores")
evt.plotting.plot_medianStationScores(list(objs.values())+[persistence],  # outputFile="../doc/source/charts/medianStationScores",
    score_list=['RMSE'], title="Median station scores as a function of the forecast term\n", file_formats=['png'])

