#! /bin/bash
#
# Evaltools installation script
# =============================
#
#    ./install.sh [OPTION] ...
#
# OPTIONS
#    -c install dependencies using anaconda instead of pip
#    -e install evaltools in editable mode (changes in evaltools' sources
#       are automatically taken into account without the need of
#       re-installation)

while getopts ec option; do
    case "${option}"
        in
        e) editable=true;;
        c) conda_install=true;;
    esac
done

# go to the script directory
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
cd $DIR

# dependences installation
if [ $conda_install ]; then
    conda install --file requirements.txt
else
    for line in $(cat requirements.txt); do
        pip install --upgrade $line
    done
fi

# evaltools installation
if [ $editable ]; then
    pip install -e .
else
    pip install .
fi
